# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in LICENSE.txt

import globals

def command_line_help():
    """Prints command line help, invoked by --help command or wrong input.
    """
    print "IMGCrush", globals.VERSION
    print "Copyright (C) 2009 Ferdinand Majerech"
    print "Usage: imgcrush [OPTION...] [FILE/DIR...]"
    print "Optimizes images for size"
    print " -h --help         display this help and exit"
    print " -o --out-dir  val directory to save optimized images to"  
    print "                   default: ./optimized/"
    print " -t --temp-dir val directory to save temp files to"
    print "                   default: ./temp/"
    print " -q --quiet        less verbose output -it's possible to use"
    print "                   this multiple times, like -qq , for even less"
    print "                   verbosity. -q will only output warnings and"
    print "                   errors, -qq will only output errors,"
    print "                   -qqq will output nothing"
    print " -v --verbose      more verbose output -works like -q"
    print " -m --prc-mult val Process multiplier. Number of processes"
    print "                   used is by default --prc-mult x 3, although"
    print "                   only one process is used when --prc-mult is 0."
    print "                   For example:"
    print "                   --prc-mult 0 : 1 process is used"
    print "                   --prc-mult 1 : 3 processes are used"
    print "                   --prc-mult 2 : 6 processes are used"
    print "                   --prc-mult 5 : 15 processes are used"
    print "                   It is recommended to set --prc-mult to number"
    print "                   of cores in your CPU."
    print "                   Default: number of CPUs on user's machine"
    print "                            or 2 if it could not be detected."
    print " -r --recur        Process directories recursively."
    print "                   If a directory is given to optimize, files"
    print "                   in its subdirectories will be optimized as well."
    print "\nFormat options:"
    print " -j --jpg          use JPG format"                                
    print "                   default: false"
    print " -p --png          use PNG format"
    print "                   default: false"
    print " -g --gif          use GIF format"
    print "                   default: false"
    print "\nJPG specific options:"
    print " -J --j-set    val profile of jpg optimization."
    print "                   --j-set sets all jpg settings so other jpg"
    print "                   commands are not needed, although they can"
    print "                   be used to override profile's settings."
    print "                   possible values:"
    print "                     extreme -best results,no speed optimizations,"
    print "                              extremely slow"
    print "                     heavy   -same results as extreme, some speed"
    print "                              optimizations, very slow"
    print "                     medium  -almost as good as heavy, more speed"
    print "                              optimizations, slow"
    print "                     light   -almost as good as medium, faster"
    print "                     fastest -worse results than light, fastest"
    print "                   default: light"
    print " -U --j-qual   val minimum quality used (1-100)"
    print "                   default: 1"
    print " -T --j-step   val step to increment quality by, i.e." 
    print "                   quality 50 with step 10 means quality"
    print "                   50,60...100 will be used (1-99)"
    print "                   default: 6"
    print " -D --j-inter      use interlacing (progressive files)"
    print "                   this usually improves size. Enabled by default."
    print " -O --j-optim      use jpg compression optimization -this"
    print "                   usually improves size. Enabled by default."
    print " -K --j-gray       use grayscale images"
    print " -Z --j-s-fact val subsampling factors to use for jpg"
    print "                   possible values:"
    print "                     standard -use most common factors:"
    print "                               1x1,2x1 and 2x2"
    print "                     all -use all available factors."
    print "                     fac1,fac2,fac3 -comma separated list of"
    print "                        factors, e.g:"
    print "                        --j-s-fact 1x1,1x2,1x4"
    print "                     available factors:"
    print "                     1x1,1x2,1x4,2x1,2x2,2x4,4x1,4x2"
    print "                    default: standard"
    print " -A --j-opt-lv val level of speed optimizations to use."
    print "                     0 -no optimizations"
    print "                     1 -lossless optimizations (results same as 0)"
    print "                     2 -more optimizations with minimally worse "
    print "                        result"
    print "                     3 -even more optimizations, somewhat worse"
    print "                     4 -all optimizations (much faster, but worse)"
    print "                    default: 3"
    print "\nPNG specific options:"
    print " -P --p-set    val profile of png optimization."
    print "                   pngall sets all png settings so other png"
    print "                   commands are not needed, although they can"
    print "                   be used to override profile's settings."
    print "                   possible values:"
    print "                     extreme -best results,no speed optimizations,"
    print "                              extremely slow"
    print "                     heavy   -same results as extreme, some speed"
    print "                              optimizations, very slow"
    print "                     medium  -not as good results, more speed"
    print "                              optimizations, slow"
    print "                     light   -worse results, faster"
    print "                     fastest -worst results, fastest"
    print "                   default: light"
    print " -L --p-lev    val minimum compression level used   (0-9)"
    print "                   default: 3"
    print " -H --p-filt   val string of filters used, i.e. to use"
    print "                   filters 0, 1 and 3 write --pngfilt 013" 
    print "                   possible values:"
    print "                     0 -no filter -best for indexed images"
    print "                     1 -sub"
    print "                     2 -up"
    print "                     3 -average"
    print "                     4 -paeth -good for truecolor images"
    print "                     5 -adaptive when level>5 and indexed"
    print "                     6 -adaptive -best for truecolor"
    print "                   default: 046"
    print " -X --p-no-tru     do not generate truecolor images"
    print " -Y --p-pal    val minimum bit depth to use for indexed"
    print "                   images -if 0, don't use indexed images"
    print "                   possible values: 1,2,4,8"
    print "                   default: 4"
    print " -R --p-gray   val minimum bit depth to use for grayscale"
    print "                   images -if 0, don't use grayscale "
    print "                   possible values: 2,4,8"
    print "                   default: 4"
    print " -E --p-inter      use interlacing -allows images to be"
    print "                   loaded progressively, usually worsens"
    print "                   size, so it's unlikely that the optimization"
    print "                   output will be interlaced"
    print " -B --p-opt-lv val level of speed optimizations to use."
    print "                     0 -no optimizations"
    print "                     1 -lossless optimizations (results same as 0)"
    print "                     2 -more optimizations with minimally worse "
    print "                        result"
    print "                     3 -even more optimizations, somewhat worse"
    print "                     4 -all optimizations (much faster, but worse)"
    print "                    default: 3"
    print "\nGIF specific options:"
    print " -G --g-set    val profile of gif optimization."
    print "                   gifall sets all gif settings so other gif"
    print "                   commands are not needed, although they can"
    print "                   be used to override profile's settings."
    print "                   possible values:"
    print "                     extreme -best results,no speed optimizations,"
    print "                              extremely slow"
    print "                     heavy   -same results as extreme, some speed"
    print "                              optimizations, very slow"
    print "                     medium  -not as good results, more speed"
    print "                              optimizations, slow"
    print "                     light   -worse results, faster"
    print "                     fastest -worst results, fastest"
    print "                   default: light"
    print " -F --g-inter      use interlaced files (progressive) -usually"
    print "                   increases file size so it's unlikely that"
    print "                   optimization output will be interlaced."
    print " -I --g-depth  val minimum bit depth to use for GIF"
    print "                   possible values: 1,2,3,4,5,6,7,8"
    print "                   default: 5"
    print " -C --g-opt-lv val level of speed optimizations to use."
    print "                     0 -no optimizations"
    print "                     1 -lossless optimizations (results same as 0)"
    print "                     2 -more optimizations with minimally worse "
    print "                        result"
    print "                     3 -even more optimizations, somewhat worse"
    print "                     4 -all optimizations (much faster, but worse)"
    print "                    default: 3"
    print "\nOptimization related options:"
    print " -N --no-strip     do not strip metadata (author, comments etc.)"
    print " -M --mode     val mode of optimization,possible values:"
    print "                     q -optimize to quality, i.e. output "
    print "                       will be the smallest file with at"
    print "                       least the given quality"
    print "                     s -optimize to size,i.e. output'll be"
    print "                        best image with at most given size"
    print " -Q --min-qual val only applies in q mode: minimum quality"
    print "                   the output can have set in %, e.g."
    print "                   --min-qual 100.0% -100% means lossless"
    print "                   quali level of speed optimizations to use."
    print "                     0 -no optimizations"
    print "                     1 -lossless optimizations (results same as 0)"
    print "               ty can also be given subjectively in "
    print "                   range from 0 to 100 without the % sign, e.g."
    print "                   --min-qual 99.2 ,in this case it's much"
    print "                   closer to jpg quality."
    print "                   default:100%"
    print " -S --max-size val only applies in s mode: maximum size the"
    print "                   output can have set in kiB,MiB,GiB,bytes,"
    print "                   % or average bits per pixel."
    print "                   e.g. --max-size 50.1kiB ,or --max-size 51303"
    print "                   when in %, e.g. --max-size 50.5%, the size is" 
    print "                   computed as percentage f size of input file," 
    print "                   when % is prefixed by r,e.g. --max-size 50.5r%" 
    print "                   size of computed as percentage of size of "
    print "                   reference file, a png file generated during"
    print "                   optimization. When using bits "
    print "                   per pixel,e.g. --max-size 2.4bpp"
    print "                   ,the maximum filesize of the image will be "
    print "                   image area * given value in bits, i.e. a"
    print "                   1024x1024 image with --max-size 2bpp will"
    print "                   take up at most 2Mb or 256kiB ."
    print "                   default:50%"
    print "\nResizing related options: (DEPRECATED)"
    print "                   Note that by default, resizing preserves"
    print "                   aspect ratio, so width and height are"
    print "                   maximum bounds of the resized image. This can"
    print "                   be changed by the --stretch option."
    print "                   If only one of width and height will be"
    print "                   specified, image will be resized to that width"
    print "                   or height, changing the other dimension to"
    print "                   preserve aspect ratio"
    print " -W --width    val width of output images in px or %, e.g.:"   
    print "                   -w 20 or -w 20%. 0 means no resizing"
    print "                   default:0"
    print " -H --height   val height of output images in px or %, e.g.:"
    print "                   -h 20 or -h 20%. 0 means no resizing"
    print "                   default:0"
    print " -s --stretch      if resized image doesn't fit given width"
    print "                   and height (has a different aspect ratio),"
    print "                   stretch the image to fill given width/height."
