# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in LICENSE.txt

from util import *

class JPGSettings:
    """Stores settings of a JPG file to generate.
    """ 
    def __init__(self, quality, interlace, optimize, samplingfactor, grayscale):
        """Constructor.

        Data members:
        Quality        : Quality level of jpg compression - higher means 
                         higher quality and filesize. Valid values : int 0-100
        Interlace      : Is this image interlaced (progressive) ?
        Optimize       : Is this image compressed with optimizations
                         (usually results in smaller filesize) ?
        SamplingFactor : Subsampling factor used on this image.
        Grayscale      : Is this image grayscale?
        """
        self.Quality = quality
        self.Interlace = interlace
        self.Optimize = optimize
        self.SamplingFactor = samplingfactor
        self.Grayscale = grayscale
    
    def str_data(self):
        """Returns a string containing jpg settings data.
        """
        return str(self.Quality) + " " + str(self.Interlace) + " "\
               + str(self.Optimize) + " " + self.SamplingFactor + " "\
               + str(self.Grayscale)

    def get_val_str(self, str):
        """Returns data member requested by the input string.
        """
        if str == "quality":
            return self.Quality
        elif str == "interlace":
            return self.Interlace
        elif str == "optimize":
            return self.Optimize
        elif str == "sampfactor":
            return self.SamplingFactor
        elif str == "grayscale":
            return self.Grayscale

class PNGSettings:
    """Stores settings of a PNG file to generate
    """ 
    def __init__(self, level, filt, mode, bitdepth, interlace, advpng=False):
        """Constructor.

        Level     : Compression level of this image -higher means lower size.
        Filter    : PNG filter used for this image.
        Mode      : Color mode of this image. e.g. truecolor, palette, etc.
        BitDepth  : Bit depth of every channel of this image.
        Interlace : Should this image be interlaced (progressive) ?
        Advpng    : Is this an image recompressed by advpng? (only one truecolor
                    and one paletted advpng per bitdepth is generated 
                    for each input file.
        """
        self.Level = level
        self.Filter = filt
        self.Mode = mode
        self.BitDepth = bitdepth
        self.Interlace = interlace
        self.Advpng = advpng
    
    def str_data(self):
        """Returns a string containing png settings data.
        """
        return str(self.Level) + " " + str(self.Filter) + " " + self.Mode +\
               " " + str(self.BitDepth) + " " + str(self.Interlace) + " " +\
               str(self.Advpng)

    def get_val_str(self, str):
        """Returns data member requested by the input string.
        """
        if str == "level":
            return self.Level
        elif str == "filter":
            return self.Filter
        elif str == "mode":
            return self.Mode
        elif str == "bitdepth":
            return self.BitDepth
        elif str == "interlace":
            return self.Interlace
        elif str == "advpng":
            return self.Advpng

class GIFSettings:
    """Stores settings of a GIF file to generate
    """ 
    def __init__(self, interlace, bitdepth):
        """Constructor.
        
        Interlace : Should this image be interlaced (progressive) ?
        BitDepth  : Bitdepth of the image (8-256 colors, 7-128, etc.)
        """
        self.Interlace = interlace
        self.BitDepth = bitdepth
    
    def str_data(self):
        """Returns a string containing gif settings data.
        """
        return str(self.Interlace) + " " + str(self.BitDepth) 

    def get_val_str(self, str):
        """Returns data member requested by the input string.
        """
        if str == "interlace":
            return self.Interlace
        if str == "bitdepth":
            return self.BitDeph

